GenericRustProxy

Struct GenericRustProxy 

pub struct GenericRustProxy<CppProxy: QCppProxy, Adapter: ?Sized> { /* private fields */ }

Implementations

Source

impl<CppProxy, Adapter> GenericRustProxy<CppProxy, Adapter>
where CppProxy: QCppProxy<ProxyRustType = Self>, Adapter: ?Sized + DispatchMetaCall,

pub fn drop_self(self_ptr: *mut Self)

Drops the instance pointed to by self_ptr.

Intended to be called exclusively from the paired C++ destructor.

self_ptr must be a pointer previously returned by QRustProxy::new. It must not have been dropped already.

pub fn invoke_slot( &self, slot_id: u32, inputs: &[*const u8], outputs: &[*mut u8], )

pub fn invoke_slot_mut( &mut self, slot_id: u32, inputs: &[*const u8], outputs: &[*mut u8], )

pub fn read_property(&self, prop_id: u32) -> QVariant

pub fn write_property(&mut self, prop_id: u32, value: &QVariant)

Source

impl GenericRustProxy<QAbstractItemModelProxyCpp, dyn QAbstractItemModelAdapter>

pub fn index(&self, row: i32, column: i32, parent: &QModelIndex) -> QModelIndex

pub fn parent(&self, child: &QModelIndex) -> QModelIndex

pub fn row_count(&self, parent: &QModelIndex) -> i32

pub fn column_count(&self, parent: &QModelIndex) -> i32

pub fn data(&self, index: &QModelIndex, role: i32) -> QVariant

pub fn role_names(&self) -> QHash<i32, QByteArray>

pub fn set_data( &mut self, index: &QModelIndex, value: &QVariant, role: i32, ) -> bool

pub fn remove_rows( &mut self, first: i32, count: i32, parent: &QModelIndex, ) -> bool

pub fn sibling(&self, row: i32, column: i32, idx: &QModelIndex) -> QModelIndex

pub fn base_role_names( &self, reference: &dyn QAbstractItemModelAdapter, ) -> QHash<i32, QByteArray>

pub fn base_set_data( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, index: &QModelIndex, value: &QVariant, role: i32, ) -> bool

pub fn base_remove_rows( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, first: i32, count: i32, parent: &QModelIndex, ) -> bool

pub fn base_sibling( &self, reference: &dyn QAbstractItemModelAdapter, row: i32, column: i32, idx: &QModelIndex, ) -> QModelIndex

pub fn base_data_changed( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, top_left: &QModelIndex, bottom_right: &QModelIndex, )

pub fn base_begin_insert_columns( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, parent: &QModelIndex, first: i32, last: i32, )

pub fn base_end_insert_columns( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, )

pub fn base_begin_insert_rows( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, parent: &QModelIndex, first: i32, last: i32, )

pub fn base_end_insert_rows( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, )

pub fn base_begin_move_columns( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, source_parent: &QModelIndex, source_first: i32, source_last: i32, destination_parent: &QModelIndex, destination_child: i32, )

pub fn base_end_move_columns( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, )

pub fn base_begin_move_rows( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, source_parent: &QModelIndex, source_first: i32, source_last: i32, destination_parent: &QModelIndex, destination_child: i32, )

pub fn base_end_move_rows( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, )

pub fn base_begin_remove_columns( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, parent: &QModelIndex, first: i32, last: i32, )

pub fn base_end_remove_columns( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, )

pub fn base_begin_remove_rows( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, parent: &QModelIndex, first: i32, last: i32, )

pub fn base_end_remove_rows( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, )

pub fn base_begin_reset_model( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, )

pub fn base_end_reset_model( &mut self, mut_ref: &mut dyn QAbstractItemModelAdapter, )

pub fn base_create_index( &self, reference: &dyn QAbstractItemModelAdapter, row: i32, column: i32, ptr: usize, ) -> QModelIndex

Source

impl GenericRustProxy<QListModelProxyCpp, dyn QListModelAdapter>

pub fn index(&self, row: i32, column: i32, parent: &QModelIndex) -> QModelIndex

pub fn row_count(&self, parent: &QModelIndex) -> i32

pub fn data(&self, index: &QModelIndex, role: i32) -> QVariant

pub fn role_names(&self) -> QHash<i32, QByteArray>

pub fn set_data( &mut self, index: &QModelIndex, value: &QVariant, role: i32, ) -> bool

pub fn remove_rows( &mut self, first: i32, count: i32, parent: &QModelIndex, ) -> bool

pub fn sibling(&self, row: i32, column: i32, idx: &QModelIndex) -> QModelIndex

pub fn base_index( &self, reference: &dyn QListModelAdapter, row: i32, column: i32, parent: &QModelIndex, ) -> QModelIndex

pub fn base_role_names( &self, reference: &dyn QListModelAdapter, ) -> QHash<i32, QByteArray>

pub fn base_set_data( &mut self, mut_ref: &mut dyn QListModelAdapter, index: &QModelIndex, value: &QVariant, role: i32, ) -> bool

pub fn base_remove_rows( &mut self, mut_ref: &mut dyn QListModelAdapter, first: i32, count: i32, parent: &QModelIndex, ) -> bool

pub fn base_sibling( &self, reference: &dyn QListModelAdapter, row: i32, column: i32, idx: &QModelIndex, ) -> QModelIndex

pub fn base_data_changed( &mut self, mut_ref: &mut dyn QListModelAdapter, top_left: &QModelIndex, bottom_right: &QModelIndex, )

pub fn base_begin_insert_rows( &mut self, mut_ref: &mut dyn QListModelAdapter, parent: &QModelIndex, first: i32, last: i32, )

pub fn base_end_insert_rows(&mut self, mut_ref: &mut dyn QListModelAdapter)

pub fn base_begin_move_rows( &mut self, mut_ref: &mut dyn QListModelAdapter, source_parent: &QModelIndex, source_first: i32, source_last: i32, destination_parent: &QModelIndex, destination_child: i32, )

pub fn base_end_move_rows(&mut self, mut_ref: &mut dyn QListModelAdapter)

pub fn base_begin_remove_rows( &mut self, mut_ref: &mut dyn QListModelAdapter, parent: &QModelIndex, first: i32, last: i32, )

pub fn base_end_remove_rows(&mut self, mut_ref: &mut dyn QListModelAdapter)

pub fn base_begin_reset_model(&mut self, mut_ref: &mut dyn QListModelAdapter)

pub fn base_end_reset_model(&mut self, mut_ref: &mut dyn QListModelAdapter)

Source

impl GenericRustProxy<QParserStatusProxyCpp, dyn QParserStatusAdapter>

pub fn class_begin(&mut self)

pub fn component_complete(&mut self)

Source

impl GenericRustProxy<QTableModelProxyCpp, dyn QTableModelAdapter>

pub fn index(&self, row: i32, column: i32, parent: &QModelIndex) -> QModelIndex

pub fn parent(&self, child: &QModelIndex) -> QModelIndex

pub fn row_count(&self, parent: &QModelIndex) -> i32

pub fn column_count(&self, parent: &QModelIndex) -> i32

pub fn data(&self, index: &QModelIndex, role: i32) -> QVariant

pub fn role_names(&self) -> QHash<i32, QByteArray>

pub fn set_data( &mut self, index: &QModelIndex, value: &QVariant, role: i32, ) -> bool

pub fn remove_columns( &mut self, first: i32, count: i32, parent: &QModelIndex, ) -> bool

pub fn remove_rows( &mut self, first: i32, count: i32, parent: &QModelIndex, ) -> bool

pub fn sibling(&self, row: i32, column: i32, idx: &QModelIndex) -> QModelIndex

pub fn base_role_names( &self, reference: &dyn QTableModelAdapter, ) -> QHash<i32, QByteArray>

pub fn base_set_data( &mut self, mut_ref: &mut dyn QTableModelAdapter, index: &QModelIndex, value: &QVariant, role: i32, ) -> bool

pub fn base_remove_columns( &mut self, mut_ref: &mut dyn QTableModelAdapter, first: i32, count: i32, parent: &QModelIndex, ) -> bool

pub fn base_remove_rows( &mut self, mut_ref: &mut dyn QTableModelAdapter, first: i32, count: i32, parent: &QModelIndex, ) -> bool

pub fn base_sibling( &self, reference: &dyn QTableModelAdapter, row: i32, column: i32, idx: &QModelIndex, ) -> QModelIndex

pub fn base_data_changed( &mut self, mut_ref: &mut dyn QTableModelAdapter, top_left: &QModelIndex, bottom_right: &QModelIndex, )

pub fn base_begin_insert_columns( &mut self, mut_ref: &mut dyn QTableModelAdapter, parent: &QModelIndex, first: i32, last: i32, )

pub fn base_end_insert_columns(&mut self, mut_ref: &mut dyn QTableModelAdapter)

pub fn base_begin_insert_rows( &mut self, mut_ref: &mut dyn QTableModelAdapter, parent: &QModelIndex, first: i32, last: i32, )

pub fn base_end_insert_rows(&mut self, mut_ref: &mut dyn QTableModelAdapter)

pub fn base_begin_move_columns( &mut self, mut_ref: &mut dyn QTableModelAdapter, source_parent: &QModelIndex, source_first: i32, source_last: i32, destination_parent: &QModelIndex, destination_child: i32, )

pub fn base_end_move_columns(&mut self, mut_ref: &mut dyn QTableModelAdapter)

pub fn base_begin_move_rows( &mut self, mut_ref: &mut dyn QTableModelAdapter, source_parent: &QModelIndex, source_first: i32, source_last: i32, destination_parent: &QModelIndex, destination_child: i32, )

pub fn base_end_move_rows(&mut self, mut_ref: &mut dyn QTableModelAdapter)

pub fn base_begin_remove_columns( &mut self, mut_ref: &mut dyn QTableModelAdapter, parent: &QModelIndex, first: i32, last: i32, )

pub fn base_end_remove_columns(&mut self, mut_ref: &mut dyn QTableModelAdapter)

pub fn base_begin_remove_rows( &mut self, mut_ref: &mut dyn QTableModelAdapter, parent: &QModelIndex, first: i32, last: i32, )

pub fn base_end_remove_rows(&mut self, mut_ref: &mut dyn QTableModelAdapter)

pub fn base_begin_reset_model(&mut self, mut_ref: &mut dyn QTableModelAdapter)

pub fn base_end_reset_model(&mut self, mut_ref: &mut dyn QTableModelAdapter)

pub fn base_create_index( &self, reference: &dyn QTableModelAdapter, row: i32, column: i32, ptr: usize, ) -> QModelIndex